pub struct DmaAlignedMut<'a, T>(/* private fields */)
where
T: ?Sized;unstable only.Expand description
A mutable reference to an InternalMemory object.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Implementations
Sourceimpl<'a, T: ?Sized> DmaAlignedMut<'a, T>
impl<'a, T: ?Sized> DmaAlignedMut<'a, T>
Sourcepub fn new(ptr: &'a mut T) -> Result<Self, DmaBufError>
pub fn new(ptr: &'a mut T) -> Result<Self, DmaBufError>
Creates a new DmaAlignedMut from a mutable variable, if it’s
provably compatible.
In internal memory, the address and size of the variable must be at least 64 byte aligned.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub const unsafe fn new_unchecked(ptr: &'a mut T) -> Self
pub const unsafe fn new_unchecked(ptr: &'a mut T) -> Self
Creates a new DmaAlignedMut from any mutable slice.
Safety
The caller must ensure that the reference is properly aligned for the memory region it occupies and the cachelines occupied by the reference do not overlap with any other data that can be corrupted by a cacheline invalidation operation.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn writeback(&mut self)
pub fn writeback(&mut self)
Writes back the data from the cache to memory.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn invalidate(&self)
pub fn invalidate(&self)
Invalidates the cache lines for this data.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn into_inner(self) -> &'a mut T
pub fn into_inner(self) -> &'a mut T
Converts this object into a mutable reference.
Sourcepub fn reborrow<'b>(&'b mut self) -> DmaAlignedMut<'b, T>
pub fn reborrow<'b>(&'b mut self) -> DmaAlignedMut<'b, T>
Reborrows this object with a different lifetime.
Sourceimpl<'a, T, const N: usize> DmaAlignedMut<'a, [T; N]>
impl<'a, T, const N: usize> DmaAlignedMut<'a, [T; N]>
Sourcepub fn unsize(self) -> DmaAlignedMut<'a, [T]>
pub fn unsize(self) -> DmaAlignedMut<'a, [T]>
Converts this object into a slice reference.